Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
var CleanupFx = fx.Options( fx.Provide( GetCleanupConfig, ), )
CleanupFx will provide the constructor method GetCleanupConfig.
Functions ¶
Types ¶
type Config ¶
type Config struct {
//Db *gorm.DB
GrpcServerConnection *grpc.Server
GrpcClientConnection *grpc.ClientConn
JaegerCloser io.Closer
}
Config CleanupConfig : cleanup config is the configuration of closing the instance. more type will be added in cleanup config if we stop or destroy the instance.
func GetCleanupConfig ¶
func GetCleanupConfig( GrpcServerConnection *grpc.Server, GrpcClientConnection *grpc.ClientConn, JaegerCloser io.Closer) *Config
GetCleanupConfig GetCleanupConfig: Get cleanup config is the constructor.
required all the closing instance
Click to show internal directories.
Click to hide internal directories.